<?php

if (!function_exists('array_safe_get')) {
    function array_safe_get(&$haystack, $needle, $default = null)
    {
        $haystack = is_array($haystack) ? $haystack : array();

        if (array_key_exists($needle, $haystack)) {
            return $haystack[$needle];
        }

        return $default;
    }
}

if (!function_exists('is_ajax_request')) {
    function is_ajax_request()
    {
        $ajaxHeader = $_SERVER['HTTP_X_REQUESTED_WITH'];

        if (!empty($ajaxHeader) && strtolower($ajaxHeader) == 'xmlhttprequest') {
            return true;
        }

        return false;
    }
}

if (!function_exists('is_post_request')) {
    function is_post_request()
    {
        return !empty($_POST);
    }
}

if (!function_exists('send_file')) {
    function send_file($filename, $download = NULL, array $options = NULL)
    {
        if (empty($download)) {
            $download = pathinfo($filename, PATHINFO_BASENAME);
        }

        $size = filesize($filename);

        if (!isset($mime)) {
            $finfo = finfo_open(FILEINFO_MIME_TYPE);

            $mime = finfo_file($finfo, $filename);

            finfo_close($finfo);
        }

        $file = fopen($filename, 'rb');

        if (!is_resource($file)) {
            throw new Exception(sprintf('Could not read file to send: %s', $download));
        }

        $disposition = empty($options['inline']) ? 'attachment' : 'inline';

        $headers = array();

        $headers['Content-Disposition'] = $disposition.'; filename="'.$download.'"';
        $headers['Content-Type'] = $mime;
        $headers['Content-Length'] = $size;

        if (!headers_sent()) {
            if (isset($_SERVER['SERVER_PROTOCOL'])) {
                $protocol = $_SERVER['SERVER_PROTOCOL'];
            } else {
                $protocol = 'HTTP/1.1';
            }

            header($protocol.' 200 OK');

            foreach ($headers as $name => $value){
                if (is_string($name)) {
                    $value = "{$name}: {$value}";
                }

                header($value, TRUE);
            }
        }

        while (ob_get_level()) {
            ob_end_flush();
        }

        ignore_user_abort(TRUE);

        set_time_limit(0);

        $block = 1024 * 16;

        while (!feof($file)) {
            if (connection_aborted()) {
                break;
            }

            echo fread($file, $block);

            flush();
        }

        fclose($file);

        if (!empty($options['delete'])) {
            try {
                unlink($filename);
            } catch (Exception $e) {}
        }

        exit;
    }
}

if (!function_exists('text_random')) {
    function text_random($length = 5)
    {
        $pool = '123456789ABCDEFGHIJKLMNPQRSTUVWXYZ';

		$pool = str_split($pool, 1);

		$max = count($pool) - 1;

		$str = '';

		for ($i = 0; $i < $length; $i++) {
            $str .= $pool[mt_rand(0, $max)];
        }

		if ($length > 1) {
            if (ctype_alpha($str)) {
                $str[mt_rand(0, $length - 1)] = chr(mt_rand(48, 57));
            } elseif (ctype_digit($str)) {
                $str[mt_rand(0, $length - 1)] = chr(mt_rand(65, 90));
            }
        }

		return $str;
    }
}

if (!function_exists('session_get_once')) {
    function session_get_once($key, $default = null)
    {
        if (array_key_exists($key, $_SESSION)) {
            $returnValue = $_SESSION[$key];
            unset($_SESSION[$key]);
        }

        return isset($returnValue) ? $returnValue : $default;
    }
}

if (!function_exists('session_set')) {
    function session_set($key, $value)
    {
        $_SESSION[$key] = $value;
    }
}

if (!function_exists('session_get')) {
    function session_get($key, $default = null)
    {
        if (array_key_exists($key, $_SESSION)) {
            return $_SESSION[$key];
        }

        return $default;
    }
}

if (!function_exists('set_flash_success')) {
    function set_flash_success($message)
    {
        $_SESSION['flash_success'] = $message;
    }
}

if (!function_exists('set_flash_warning')) {
    function set_flash_warning($message)
    {
        $_SESSION['flash_warning'] = $message;
    }
}

if (!function_exists('set_flash_error')) {
    function set_flash_error($message)
    {
        $_SESSION['flash_error'] = $message;
    }
}

if (!function_exists('get_flash_success')) {
    function get_flash_success()
    {
        return session_get_once('flash_success');
    }
}

if (!function_exists('get_flash_error')) {
    function get_flash_error()
    {
        return session_get_once('flash_error');
    }
}

if (!function_exists('get_flash_warning')) {
    function get_flash_warning()
    {
        return session_get_once('flash_warning');
    }
}

if (!function_exists('security_session_token')) {
    function security_session_token($new = false)
    {
        if ($new) {
            $securityToken = text_random();

            session_set('security_token', $securityToken);

            return $securityToken;
        }

        return session_get('security_token');
    }
}