<?php

function handle_smsapi_exception(Exception $error)
{
    $invalid_authorization_data_error_codes = array(101, 401);

    if (in_array($error->getCode(), $invalid_authorization_data_error_codes)) {
        set_flash_error(__('Invalid authorization data. Please make sure that you have selected correct domain.', 'smsapi'));

        SmsapiConfig::requireReconfiguration();

        $config = SmsapiConfig::getApiClientConfig();

        include_once SMSAPI_PLUGIN_PATH . "/views/admin/settings/general.php";
    } else {
        set_flash_error(__('Something went wrong. Please try again later.', 'smsapi'));
        include_once SMSAPI_PLUGIN_PATH . "/views/admin/error.php";
    }
}

function smsapi_gateway_routing()
{
    $recipientsNumbers = session_get_once('gateway_recipients', array());

    try {
        action_gateway($recipientsNumbers);
    } catch (\SMSApi\Exception\SmsapiException $error) {
        handle_smsapi_exception($error);
    }
}

function smsapi_settings_routing()
{
    try {
        $tab = array_safe_get($_GET, 'tab');

        if($tab == 'subscription') {
            action_settings_subscription();
        } elseif($tab == 'notifications') {
            action_settings_notifications();
        } else {
            if (SmsapiConfig::isCofigurationGeneralCompleted()) {
                action_settings_general_ext();
            } else {
                action_settings_general();
            }

        }
    } catch (\SMSApi\Exception\SmsapiException $error) {
        handle_smsapi_exception($error);
    }
}

function smsapi_subscribers_routing()
{
    try {
        if (!$action = array_safe_get($_GET, 'action')) {
            $action = array_safe_get($_POST, 'action');
        }

        if ($action == 'edit') {
            $subscriberId = array_safe_get($_GET, 'id');
            action_subscribers_edit($subscriberId);
        } elseif ($action == 'delete') {
            $subscriberId = array_safe_get($_GET, 'id');
            action_remove_one($subscriberId);
        } elseif ($action == 'remove') {
            $subscribersIds = array_safe_get($_POST, 'subscribers_ids', array());
            action_remove_by_ids($subscribersIds);
        } elseif ($action == 'remove_all') {
            action_remove_all();
        } elseif ($action == 'sendsms') {
            $subscribersIds = array_safe_get($_POST, 'subscribers_ids', array());
            action_sendsms($subscribersIds);
        } elseif ($action == 'export') {
            $subscribersIds = array_safe_get($_POST, 'subscribers_ids', array());
            action_export($subscribersIds);
        } elseif ($action == 'export_all') {
            action_export_all();
        } else {
            action_subscribers_list();
        }
    } catch (\SMSApi\Exception\SmsapiException $error) {
        handle_smsapi_exception($error);
    }
}
 